from sklearn.metrics import accuracy_score


def baseline_score_clf(data, target):
    data[target].value_counts(normalize=True)
    majority_class = data[target].mode()[0]
    y_pred = [majority_class] * len(data)
    baseline_score = int(round(accuracy_score(data[target],
                                              y_pred), 2) * 100)
    print(f"Baseline Accuracy Score: {baseline_score}")


def cut_cardinality(data, threshold=50):
    cardinality = data.select_dtypes(exclude='number').nunique()
    categorical_features = cardinality[cardinality <= threshold].index.tolist()
    return categorical_features



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="dustydata",
    version="0.0.4",
    author="Dustin Stringer",
    author_email="dustinstri92@gmail.com",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/dustin-py/Packages/tree/master/dustydata",
    packages=setuptools.find_packages(),
    python_requires='>=3.6'
)
